@@ -144,8 +144,9 @@ class SocialAuthBackend(ModelBackend):
             username = settings.SOCIAL_AUTH_DEFAULT_USERNAME
             if callable(username):
                 username = username()
-        if not username:
-            username = get_random_username()
+        else:
+            username = None
+        username = username or get_random_username()
 
         fixer = getattr(settings, 'SOCIAL_AUTH_USERNAME_FIXER', lambda u: u)
 
@@ -154,9 +155,10 @@ class SocialAuthBackend(ModelBackend):
 
         while not final_username:
             try:
-                User.objects.get(username=fixer(name))
+                fixed_name = fixer(name)
+                User.objects.get(username=fixed_name)
             except User.DoesNotExist:
-                final_username = name
+                final_username = fixed_name
             else:
                 # User with same username already exists, generate a unique
                 # username for current user using username as base but adding
